==> v0.9.zip: lazydocker/docs/keybindings/Keybindings_nl.md <==
# Lazydocker menu

## Project

<pre>
  <kbd>e</kbd>: verander de lazydocker configuratie
  <kbd>o</kbd>: open de lazydocker configuratie
  <kbd>[</kbd>: vorige tab
  <kbd>]</kbd>: volgende tab
  <kbd>m</kbd>: bekijk logs
  <kbd>enter</kbd>: focus hooft panneel
</pre>

## Containers

<pre>
  <kbd>[</kbd>: vorige tab
  <kbd>]</kbd>: volgende tab
  <kbd>d</kbd>: verwijder
  <kbd>e</kbd>: Verberg gestopte containers
  <kbd>s</kbd>: stop
  <kbd>r</kbd>: herstart
  <kbd>a</kbd>: verbinden
  <kbd>m</kbd>: bekijk logs
  <kbd>c</kbd>: draai een vooraf bedacht aangepaste opdracht
  <kbd>b</kbd>: view bulk commands
  <kbd>enter</kbd>: focus hooft panneel
</pre>

## Diensten

<pre>
  <kbd>d</kbd>: verwijder containers
  <kbd>s</kbd>: stop
  <kbd>r</kbd>: herstart
  <kbd>a</kbd>: verbinden
  <kbd>m</kbd>: bekijk logs
  <kbd>[</kbd>: vorige tab
  <kbd>]</kbd>: volgende tab
  <kbd>R</kbd>: bekijk herstart opties
  <kbd>c</kbd>: draai een vooraf bedacht aangepaste opdracht
  <kbd>b</kbd>: view bulk commands
  <kbd>enter</kbd>: focus hooft panneel
</pre>

## Images

<pre>
  <kbd>[</kbd>: vorige tab
  <kbd>]</kbd>: volgende tab
  <kbd>c</kbd>: draai een vooraf bedacht aangepaste opdracht
  <kbd>d</kbd>: verwijder image
  <kbd>b</kbd>: view bulk commands
  <kbd>enter</kbd>: focus hooft panneel
</pre>

## Volumes

<pre>
  <kbd>[</kbd>: vorige tab
  <kbd>]</kbd>: volgende tab
  <kbd>c</kbd>: draai een vooraf bedacht aangepaste opdracht
  <kbd>d</kbd>: verwijder volume
  <kbd>b</kbd>: view bulk commands
  <kbd>enter</kbd>: focus hooft panneel
</pre>

## Hooft

<pre>
  <kbd>esc</kbd>: terug
</pre>

==> v0.18.1.zip: lazydocker/docs/keybindings/Keybindings_nl.md <==
# Lazydocker menu

## Project

<pre>
  <kbd>e</kbd>: verander de lazydocker configuratie
  <kbd>o</kbd>: open de lazydocker configuratie
  <kbd>[</kbd>: vorige tab
  <kbd>]</kbd>: volgende tab
  <kbd>m</kbd>: bekijk logs
  <kbd>enter</kbd>: focus hoofdpaneel
</pre>

## Containers

<pre>
  <kbd>[</kbd>: vorige tab
  <kbd>]</kbd>: volgende tab
  <kbd>d</kbd>: verwijder
  <kbd>e</kbd>: Verberg gestopte containers
  <kbd>s</kbd>: stop
  <kbd>r</kbd>: herstart
  <kbd>a</kbd>: verbinden
  <kbd>m</kbd>: bekijk logs
  <kbd>E</kbd>: exec shell
  <kbd>c</kbd>: draai een vooraf bedacht aangepaste opdracht
  <kbd>b</kbd>: view bulk commands
  <kbd>w</kbd>: open in browser (first port is http)
  <kbd>enter</kbd>: focus hoofdpaneel
</pre>

## Diensten

<pre>
  <kbd>d</kbd>: verwijder containers
  <kbd>s</kbd>: stop
  <kbd>r</kbd>: herstart
  <kbd>a</kbd>: verbinden
  <kbd>m</kbd>: bekijk logs
  <kbd>[</kbd>: vorige tab
  <kbd>]</kbd>: volgende tab
  <kbd>R</kbd>: bekijk herstart opties
  <kbd>c</kbd>: draai een vooraf bedacht aangepaste opdracht
  <kbd>b</kbd>: view bulk commands
  <kbd>w</kbd>: open in browser (first port is http)
  <kbd>enter</kbd>: focus hoofdpaneel
</pre>

## Images

<pre>
  <kbd>[</kbd>: vorige tab
  <kbd>]</kbd>: volgende tab
  <kbd>c</kbd>: draai een vooraf bedacht aangepaste opdracht
  <kbd>d</kbd>: verwijder image
  <kbd>b</kbd>: view bulk commands
  <kbd>enter</kbd>: focus hoofdpaneel
</pre>

## Volumes

<pre>
  <kbd>[</kbd>: vorige tab
  <kbd>]</kbd>: volgende tab
  <kbd>c</kbd>: draai een vooraf bedacht aangepaste opdracht
  <kbd>d</kbd>: verwijder volume
  <kbd>b</kbd>: view bulk commands
  <kbd>enter</kbd>: focus hoofdpaneel
</pre>

## Hoofd

<pre>
  <kbd>esc</kbd>: terug
</pre>
